@@ -3,9 +3,7 @@
 // All Rights Reserved.
 //
 // NOTICE:  Adobe permits you to use, modify, and distribute this file in accordance with the terms
-// of the Adobe license agreement accompanying it. If you have received this file from a source other 
-// than Adobe, then your use, modification, or distribution of it requires the prior written permission
-// of Adobe.
+// of the Adobe license agreement accompanying it. 
 // =================================================================================================
 
 #include "public/include/XMP_Environment.h"	// ! Must be the first #include!
@@ -148,7 +146,7 @@ void ExpatAdapter::ParseBuffer ( const void * buffer, size_t length, bool last /
 	
 	#if BanAllEntityUsage
 		if ( this->isAborted ) {
-			XMP_Error error(kXMPErr_BadXML, "DOCTYPE is not allowed" )
+			XMP_Error error(kXMPErr_BadXML, "DOCTYPE is not allowed" );
 			this->NotifyClient ( kXMPErrSev_Recoverable, error );
 		}
 	#endif
